
package Class::Lego;

use 5.006;
use strict;
use warnings;

our $VERSION = '0.004';

1;

=head1 NAME

Class::Lego - Build your classes with basic building blocks

=head1 SYNOPSIS

  use Class::Lego;

  # soon

=head1 DESCRIPTION

Not ready yet. The first pieces are L<Class::Lego::Myself>
and L<Class::Lego::Constructor>.

=head1 BUGS

Please report bugs via CPAN RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-Lego>
or L<mailto://bugs-Class-Lego@rt.cpan.org>.

=head1 AUTHORS

Adriano R. Ferreira, E<lt>ferreira@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008 by Adriano R. Ferreira

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut





